+++
title = "Title with *lots and lots of * aste*risks**"
tags = ["title"]
draft = false
+++

-   All asterisk characters meant for Org `*bold*` markup are removed.
-   The rest of the asterisk characters are retained.
